@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.044'; # TRIAL
+our $VERSION = '1.046'; # TRIAL
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -133,7 +133,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.044
+version 1.046
 
 =head1 SYNOPSIS
 
@@ -426,11 +426,63 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords bj5004 cm-perl Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Philipp Gortan Stephen Thirlwall
+
+=over 4
+
+=item *
+
+bj5004 <bartosz.jakubski@hurra.com>
+
+=item *
+
+cm-perl <cm-perl@users.noreply.github.com>
+
+=item *
+
+Lucas Kanashiro <kanashiro.duarte@gmail.com>
+
+=item *
+
+Maros Kollar <maros.kollar@geizhals.at>
+
+=item *
+
+Maxim Vuets <maxim.vuets@booking.com>
+
+=item *
+
+mephinet <mephinet@gmx.net>
+
+=item *
+
+Philipp Gortan <philipp.gortan@apa.at>
+
+=item *
+
+Stephen Thirlwall <sdt@dr.com>
+
+=item *
+
+Stephen Thirlwall <stephen.thirlwall@strategicdata.com.au>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
