@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Util;
 
 # ABSTRACT: Common utility functions for Log::Any
-our $VERSION = '1.044'; # TRIAL
+our $VERSION = '1.046'; # TRIAL
 
 use Exporter;
 our @ISA = qw/Exporter/;
@@ -241,7 +241,7 @@ Log::Any::Adapter::Util - Common utility functions for Log::Any
 
 =head1 VERSION
 
-version 1.044
+version 1.046
 
 =head1 DESCRIPTION
 
@@ -249,60 +249,58 @@ This module has utility functions to help develop L<Log::Any::Adapter>
 subclasses or L<Log::Any::Proxy> formatters/filters.  It also has some
 functions used in internal testing.
 
-=head1 FUNCTIONS
-
-=head2 logging_methods
+=func logging_methods
 
 Returns a list of all logging method. E.g. "trace", "info", etc.
 
-=head2 detection_methods
+=func detection_methods
 
 Returns a list of detection methods.  E.g. "is_trace", "is_info", etc.
 
-=head2 logging_and_detection_methods
+=func logging_and_detection_methods
 
 Returns a list of logging and detection methods (but not aliases).
 
-=head2 log_level_aliases
+=func log_level_aliases
 
 Returns key/value pairs mapping aliases to "official" names.  E.g. "err" maps
 to "error".
 
-=head2 logging_aliases
+=func logging_aliases
 
 Returns a list of logging alias names.  These are the keys from
 L</log_level_aliases>.
 
-=head2 detection_aliases
+=func detection_aliases
 
 Returns a list of detection aliases.  E.g. "is_err", "is_fatal", etc.
 
-=head2 numeric_level
+=func numeric_level
 
 Given a level name (or alias), returns the numeric value described above under
 log level constants.  E.g. "err" would return 3.
 
-=head2 dump_one_line
+=func dump_one_line
 
 Given a reference, returns a one-line L<Data::Dumper> dump with keys sorted.
 
-=head2 make_method
+=func make_method
 
 Given a method name, a code reference and a package name, installs the code
 reference as a method in the package.
 
-=head2 require_dynamic (DEPRECATED)
+=func require_dynamic (DEPRECATED)
 
 Given a class name, attempts to load it via require unless the class
 already has a constructor available.  Throws an error on failure. Used
 internally and may become private in the future.
 
-=head2 read_file (DEPRECATED)
+=func read_file (DEPRECATED)
 
 Slurp a file.  Does *not* apply any layers.  Used for testing and may
 become private in the future.
 
-=head2 cmp_deeply (DEPRECATED)
+=func cmp_deeply (DEPRECATED)
 
 Compares L<dump_one_line> results for two references.  Also takes a test
 label as a third argument.  Used for testing and may become private in the
@@ -343,11 +341,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
