@@ -4,7 +4,7 @@ use warnings;
 
 package Log::Any::Manager;
 
-our $VERSION = '1.044'; # TRIAL
+our $VERSION = '1.046'; # TRIAL
 
 sub new {
     my $class = shift;
@@ -241,7 +241,7 @@ Log::Any::Manager
 
 =head1 VERSION
 
-version 1.044
+version 1.046
 
 =head1 AUTHORS
 
@@ -259,11 +259,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
