@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.044'; # TRIAL
+our $VERSION = '1.046'; # TRIAL
 
 use Log::Any::Adapter::Util ();
 use overload;
@@ -17,9 +17,9 @@ sub _default_formatter {
       map {
            !defined($_) ? '<undef>'
           : ref($_)     ? (
-	        overload::OverloadedStringify($_) ? "$_"
-	      : Log::Any::Adapter::Util::dump_one_line($_)
-	    )
+            overload::OverloadedStringify($_) ? "$_"
+          : Log::Any::Adapter::Util::dump_one_line($_)
+        )
           : $_
       } @params;
     # Perl 5.22 adds a 'redundant' warning if the number parameters exceeds
@@ -115,7 +115,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.044
+version 1.046
 
 =head1 SYNOPSIS
 
@@ -277,11 +277,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
